- Home
- Terms of Service
- Privacy Policy
- Contact Information

# Zeitgitter Server at ZEITGITTER_DOMAIN

Zeitgitter is the foundation of a network of timestamping services operating on standard GIT mechanisms.

## Zeitgitter?

Learn more about timestamping, Zeitgitter, the Zeitgitter network, how to use it, and how to join it at zeitgitter.net.

## Why timestamping?

Timestamping serves as evidence that you knew about a specific piece of information at a given time, and maybe even before. It can therefore be seen as a weak form of notarization for the particular single document (or collection of documents) that was timestamped.

Timestamping does not provide evidence that you also authored the information or you were authorized to know it.

## Why timestamping with GIT and Zeitgitter?

Timestamping GIT repositories has the following advantages:

- No additional software is required to verify the timestamps.
- No document needs to be modified to timestamp it.
- No hashes of documents are published, only IDs of your commits.
- Timestamps are cumulative, i.e., any commits which are ancestors of a timestamp are implicitely timestamped as well.

The design considerations of Zeitgitter also come with the following features:

- Timestamps are issued in real time: You get a timestamp in a matter of seconds, at most.
- The timestamping process results in a valid timestamped signature, which you can immediately store in your GIT repository.

All the remaining mumbo-jumbo is just to ensure that timestampers are not mis-issuing any backdated timestamps and that this can also be publicly audited at any time, to answer the question: But who will guard the guards themselves?

- The audit log for the timestamps is a GIT repository as well, i.e., the input and the output formats are compatible. This follows the Unix component and stdio principle and allows such logs to be timestamped by other Zeitgitter servers as well.
- As a result, a network of timestampers can be built, cross-timestamping each other.
- Any trustworthy cross-timestamp limits the ability of the receiving timestamper to maliciously issue wrong timestamps. Especially, it is not possible to issue a timestamp after a trustworthy cross-timestamp claiming to have been issued before this cross-timestamp.
- As a result, already a single trustworthy timestamper in the entire network can greatly limit the freedom of any other timestamper to issue backdated timestamps. This is in stark contrast to other distributed systems, where slightly more than one third or one half of malicious nodes can control the entire network.